==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1EvictionFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta1EvictionFluent<A extends V1beta1EvictionFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    
/**
 * This method has been deprecated, please use method buildDeleteOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1DeleteOptions getDeleteOptions();
    public V1DeleteOptions buildDeleteOptions();
    public A withDeleteOptions(V1DeleteOptions deleteOptions);
    public Boolean hasDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> withNewDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> withNewDeleteOptionsLike(V1DeleteOptions item);
    public V1beta1EvictionFluent.DeleteOptionsNested<A> editDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> editOrNewDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> editOrNewDeleteOptionsLike(V1DeleteOptions item);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> withNewMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1EvictionFluent.MetadataNested<A> editMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);

    public interface DeleteOptionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1DeleteOptionsFluent<V1beta1EvictionFluent.DeleteOptionsNested<N>>{

        
    public N and();    public N endDeleteOptions();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1EvictionFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1EvictionFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta1EvictionFluent<A extends V1beta1EvictionFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDeleteOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1DeleteOptions getDeleteOptions();
    public V1DeleteOptions buildDeleteOptions();
    public A withDeleteOptions(V1DeleteOptions deleteOptions);
    public Boolean hasDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> withNewDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> withNewDeleteOptionsLike(V1DeleteOptions item);
    public V1beta1EvictionFluent.DeleteOptionsNested<A> editDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> editOrNewDeleteOptions();
    public V1beta1EvictionFluent.DeleteOptionsNested<A> editOrNewDeleteOptionsLike(V1DeleteOptions item);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> withNewMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1EvictionFluent.MetadataNested<A> editMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1EvictionFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);

    public interface DeleteOptionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1DeleteOptionsFluent<V1beta1EvictionFluent.DeleteOptionsNested<N>>{

        
    public N and();    public N endDeleteOptions();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1EvictionFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
